@@ -2,11 +2,11 @@
 
 Implements the Distutils 'build_scripts' command."""
 
-# This module should be kept compatible with Python 1.5.2.
+# This module should be kept compatible with Python 2.1.
 
-__revision__ = "$Id: build_scripts.py 35629 2004-04-01 03:56:46Z fdrake $"
+__revision__ = "$Id$"
 
-import sys, os, re
+import os, re
 from stat import ST_MODE
 from distutils import sysconfig
 from distutils.core import Command
@@ -24,6 +24,7 @@ class build_scripts (Command):
     user_options = [
         ('build-dir=', 'd', "directory to \"build\" (copy) to"),
         ('force', 'f', "forcibly build everything (ignore file timestamps"),
+        ('executable=', 'e', "specify final destination interpreter path"),
         ]
 
     boolean_options = ['force']
@@ -33,12 +34,14 @@ class build_scripts (Command):
         self.build_dir = None
         self.scripts = None
         self.force = None
+        self.executable = None
         self.outfiles = None
 
     def finalize_options (self):
         self.set_undefined_options('build',
                                    ('build_scripts', 'build_dir'),
-                                   ('force', 'force'))
+                                   ('force', 'force'),
+                                   ('executable', 'executable'))
         self.scripts = self.distribution.scripts
 
     def get_source_files(self):
@@ -94,21 +97,23 @@ class build_scripts (Command):
                 if not self.dry_run:
                     outf = open(outfile, "w")
                     if not sysconfig.python_build:
-                        outf.write("#!%s%s\n" % 
-                                   (os.path.normpath(sys.executable),
+                        outf.write("#!%s%s\n" %
+                                   (self.executable,
                                     post_interp))
                     else:
                         outf.write("#!%s%s\n" %
                                    (os.path.join(
                             sysconfig.get_config_var("BINDIR"),
-                            "python" + sysconfig.get_config_var("EXE")),
+                           "python%s%s" % (sysconfig.get_config_var("VERSION"),
+                                           sysconfig.get_config_var("EXE"))),
                                     post_interp))
                     outf.writelines(f.readlines())
                     outf.close()
                 if f:
                     f.close()
             else:
-                f.close()
+                if f:
+                    f.close()
                 self.copy_file(script, outfile)
 
         if os.name == 'posix':
